Package: DeductiveR
Type: Package
Title: Deductive Rational Method
Version: 2.0.0
Date: 2026-05-08
Authors@R: person("Alonso", "Arriagada", email = "alonso.arriagada@usach.cl",
                  role = c("aut", "cre"))
Description: Apply the Deductive Rational Method to a monthly series of flow or precipitation data to fill in missing data. The method is as described in: Campos, D.F., (1984, ISBN:9686194444). 
License: GPL-3
LazyData: true
Encoding: UTF-8
Imports: dplyr, tidyr, ggplot2, moments, ggpubr, lmomco
Suggests: rmarkdown, knitr
VignetteBuilder: knitr
Depends: R (>= 2.10)
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-19 21:20:31 UTC; alobo
Author: Alonso Arriagada [aut, cre]
Maintainer: Alonso Arriagada <alonso.arriagada@usach.cl>
Repository: CRAN
Date/Publication: 2026-05-19 21:30:19 UTC
Built: R 4.5.2; ; 2026-05-19 23:58:40 UTC; unix
