#' Monthly flow data from Estero Culebron DGA station
#'
#' A dataset containing dates and monthly flow values.
#'
#' @format A data frame with 480 rows and 5 variables:
#' \describe{
#'   \item{date}{dates}
#'   \item{year}{years}
#'   \item{month}{months}
#'   \item{day}{days}
#'   \item{4400001}{flows, in cubic meters per second}
#' }
#' @source \url{https://camels.cr2.cl/}
"data"
