## Global variables for R CMD check

# Define global variables to avoid "no visible binding for global variable" notes during R CMD check
# vARIABLES: Exd_Probb Mean Month Month_abb Month_num Type Value day month station year

utils::globalVariables(c("Exd_Probb", "Mean", "Month", "Month_abb", "Month_num", "Type", "Value", "day", "month", "station", "year"))
