% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DR_stats_package.R
\name{DR_stats}
\alias{DR_stats}
\title{Statistics for the result from the application of the Deductive Rational Method}
\usage{
DR_stats(dr)
}
\arguments{
\item{dr}{data frame from DR function}
}
\description{
Statistics for the result from the application of the Deductive Rational Method
}
